gtoolz.Transcript

# ``gtoolz`.`Transcript``

class documentation

`class Transcript:`

View In Hierarchy

Transcript - direct print output to a file, in addition to terminal. It appends the file target Usage: import transcript transcript.start('logfile.log') print("inside file") transcript.stop() print("outside file") Requires: import sys class Transcript def transcript_start def transcript_stop

Method | `__init__` | Undocumented
Method | `flush` | Undocumented
Method | `write` | Undocumented
Instance Variable | `logfile` | --== SEP_LINE ==--
Instance Variable | `terminal` | Undocumented

def __init__(self, filename):

Undocumented

def flush(self):

Undocumented

def write(self, message):

Undocumented

logfile =

--== SEP_LINE ==--

terminal =

Undocumented